@@ -4,7 +4,9 @@ OC.L10N.register(
     "Notes" : "Nodiadau",
     "Error" : "Gwall",
     "New note" : "Nodyn newydd",
-    "Settings" : "Gosodiadau",
+    "Display mode for notes" : "Modd arddangos nodiadau",
+    "Open in edit mode" : "Agor yn y modd golygu",
+    "Open in preview mode" : "Agor yn y modd rhagolwg",
     "No notes yet" : "Dim nodiadau eto",
     "All notes" : "Pob nodyn",
     "Loading …" : "Yn llwytho …",
