@@ -13,11 +13,13 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
     "_Deleted {number} note_::_Deleted {number} notes_" : ["פתק אחד נמחק","{number} פתקים נמחקו","{number} פתקים נמחקו","{number} פתקים נמחקו"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["פתק אחד שוחזר","{number} פתקים שוחזרו","{number} פתקים שוחזרו","{number} פתקים שוחזרו"],
-    "Settings" : "הגדרות",
     "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
-    "path to notes" : "נתיב לפתקיות",
     "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
+    "Display mode for notes" : "מצב תצוגת פתקים",
+    "Open in edit mode" : "פתיחה במצב עריכה",
+    "Open in preview mode" : "פתיחה במצב תצוגה מקדימה",
     "No notes yet" : "אין פתקים עדיין",
+    "Insert image" : "הוספת תמונה",
     "All notes" : "כל הפתקים",
     "Categories" : "קטגוריות",
     "Loading …" : "בטעינה",
@@ -33,6 +35,7 @@ OC.L10N.register(
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
     "Error during preparing note for deletion." : "שגיאה במהלך הכנת הפתק למחיקה.",
+    "Use current version" : "להשתמש בגרסה הנוכחית",
     "Empty note" : "פתק ריק",
     "Write …" : "כתיבה…",
     "Details" : "פרטים",
